#
# spec file for package libXrandr
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libXrandr
%define lname   libXrandr2
Version:        1.5.4
Release:        1.5
Summary:        X Resize, Rotate and Reflection extension library
License:        MIT
Group:          Development/Libraries/C and C++
URL:            http://xorg.freedesktop.org/

#Git-Clone:	git://anongit.freedesktop.org/xorg/lib/libXrandr
#Git-Web:	http://cgit.freedesktop.org/xorg/lib/libXrandr/
Source:         http://xorg.freedesktop.org/releases/individual/lib/%{name}-%{version}.tar.xz
Source1:        baselibs.conf
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

#git#BuildRequires:	autoconf >= 2.60, automake, libtool
BuildRequires:  fdupes
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(randrproto) >= 1.5
BuildRequires:  pkgconfig(renderproto)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xextproto)
BuildRequires:  pkgconfig(xorg-macros) >= 1.8
BuildRequires:  pkgconfig(xrender)

%description
The X Resize, Rotate and Reflect Extension (RandR) allows clients to
dynamically change X screens, so as to resize, to change the
orientation and layout of the root window of a screen.

%package -n %lname
Summary:        X Resize, Rotate and Reflection extension library
Group:          System/Libraries

%description -n %lname
The X Resize, Rotate and Reflect Extension (RandR) allows clients to
dynamically change X screens, so as to resize, to change the
orientation and layout of the root window of a screen.

%package devel
Summary:        Development files for the X Resize-Rotate-Reflection library
Group:          Development/Libraries/C and C++
Requires:       %lname = %version

%description devel
The X Resize, Rotate and Reflect Extension (RandR) allows clients to
dynamically change X screens, so as to resize, to change the
orientation and layout of the root window of a screen.

This package contains the development headers for the library found
in %lname.

%prep
%setup -q

%build
#git#autoreconf -fi
%configure --disable-static
make %{?_smp_mflags}

%install
make install DESTDIR="%buildroot"
rm -f "%buildroot/%_libdir"/*.la
%fdupes %buildroot/%_prefix

%post -n %lname -p /sbin/ldconfig

%postun -n %lname -p /sbin/ldconfig

%files -n %lname
%defattr(-,root,root)
%_libdir/libXrandr.so.2*

%files devel
%defattr(-,root,root)
%_includedir/X11/*
%_libdir/libXrandr.so
%_libdir/pkgconfig/xrandr.pc
%_mandir/man3/*

%changelog
* Thu Oct  5 2023 Stefan Dirsch <sndirsch@suse.com>
- Update to version 1.5.4
  This release fixes a bug where an invalid pointer (a pointer to the
  middle of a buffer returned from malloc() instead of to the beginning
  of the buffer) could be passed to free() when cleaning up after an
  out-of-bounds output is found in the response from the X server to
  XRRGetMonitors().
* Sun Nov 20 2022 Stefan Dirsch <sndirsch@suse.com>
- Update to version 1.5.3
  * Fix spelling/wording issues
  * gitlab CI: add a basic build test
  * Xrandr.h: remove misleading comment for XRRGetScreenSizeRange()
  * XRRGetProviderInfo: Remove unneeded ProviderInfoExtra
  * Variable scope reductions as recommended by cppcheck
  * Remove unnecessary casts of return values from malloc()
* Fri Mar 22 2019 Stefan Dirsch <sndirsch@suse.com>
- Update to version 1.5.2
  * autogen: add default patch prefix
  * autogen.sh: use quoted string variables
  * autogen.sh: use exec instead of waiting for configure to finish
  * Update configure.ac bug URL for gitlab migration
  * Fix memory leak on error paths
  * Add description of libXrandr to README.md
  * Update README for gitlab migration
- supersedes U_libXrandr_fix-memory-leak.patch
* Wed Nov 22 2017 zaitor@opensuse.org
- Add U_libXrandr_fix-memory-leak.patch: Fix memory leak on error
  paths.
- Drop unneeded autoconf, automake and libtool BuildRequires and no
  longer pass autoreconf.
* Mon May 29 2017 sndirsch@suse.com
- includes everything needed for missing sle issue entries:
  fate #320388, bnc#1003000, CVE-2016-7947, CVE-2016-7948 (bsc#1041366)
* Thu Oct  6 2016 sndirsch@suse.com
- Update to version 1.5.1
  * Avoid out of boundary accesses on illegal responses
    (bnc#1003000, CVE-2016-7947, CVE-2016-7948)
  * fix: doGetScreenResources() info: redundant null check on
    calling free()
  * fix: redundant null check on calling free()
* Wed Dec 16 2015 fcrozat@suse.com
- update BuildRequires to pkgconfig(randrproto) >= 1.5
* Mon May 18 2015 sndirsch@suse.com
- added baselibs.conf as source in specfile
* Sun May 17 2015 tobias.johannes.klausmann@mni.thm.de
- Update to version 1.5.0:
  Add support for monitors and fixes requires on libX11.
* Sun Sep  8 2013 tobias.johannes.klausmann@mni.thm.de
- Update to version 1.4.2:
  This release fixes two small bugs in the library, and fixes an omission
  in the list of copyright notices in the COPYING file.
* Sat Jun  1 2013 tobias.johannes.klausmann@mni.thm.de
- Update to version 1.4.1:
  This release brings the fixes for the recently announced security issue
  CVE-2013-1986, with some related hardening to avoid other issues, alongside
  a couple small build configuration & compiler warning fixes.
* Sun Feb 17 2013 jengelh@inai.de
- Use more robust make install call
- Avoid calling fdupes outside of /usr
* Fri Jul 27 2012 tobias.johannes.klausmann@mni.thm.de
- Update to version 1.4.0:
  + Strip trailing whitespace
  + Fill in nameLen in XRROutputInfo
  + libXrandr: add support for provider objects.
* Wed Apr 11 2012 vuntz@opensuse.org
- Update to version 1.3.2:
  + Man page improvements
  + Build configuration improvements
* Tue Feb  7 2012 jengelh@medozas.de
- Split xorg-x11-libs into separate packages
